==> riece-1.19-pkg.tar.gz: lisp/riece/custom-load.el <==
;;; custom-load.el --- automatically extracted custom dependencies

;;; Code:

(autoload 'custom-add-loads "cus-load")

(custom-add-loads 'riece-yank '("riece-yank"))
(custom-add-loads 'riece-ignore '("riece-ignore"))
(custom-add-loads 'riece-guess '("riece-guess"))
(custom-add-loads 'riece-keepalive '("riece-keepalive"))
(custom-add-loads 'riece-coding '("riece-coding"))
(custom-add-loads 'riece-doctor '("riece-doctor"))
(custom-add-loads 'riece-history '("riece-history"))
(custom-add-loads 'riece-async '("riece-async"))
(custom-add-loads 'riece-keyword '("riece-keyword"))
(custom-add-loads 'riece-addon '("riece-addon"))
(custom-add-loads 'riece-url '("riece-url"))
(custom-add-loads 'riece-alias '("riece-alias"))
(custom-add-loads 'riece-looks '("riece-options"))
(custom-add-loads 'riece-channel '("riece-options"))
(custom-add-loads 'riece-addon-list '("riece-addon"))
(custom-add-loads 'riece-highlight '("riece-highlight"))
(custom-add-loads 'riece-biff '("riece-biff"))
(custom-add-loads 'riece-message '("riece-message"))
(custom-add-loads 'riece-eval '("riece-eval"))
(custom-add-loads 'riece-log '("riece-log"))
(custom-add-loads 'riece-ndcc '("riece-ndcc"))
(custom-add-loads 'riece-rdcc '("riece-rdcc"))
(custom-add-loads 'riece-google '("riece-google"))
(custom-add-loads 'riece-ctlseq '("riece-ctlseq"))
(custom-add-loads 'riece-addon-list-faces '("riece-addon"))
(custom-add-loads 'riece '("riece-addon" "riece-alias" "riece-async" "riece-biff" "riece-coding" "riece-ctlseq" "riece-doctor" "riece-eval" "riece-google" "riece-guess" "riece-hangman" "riece-highlight" "riece-history" "riece-ignore" "riece-keepalive" "riece-keyword" "riece-layout" "riece-log" "riece-message" "riece-mini" "riece-ndcc" "riece-options" "riece-rdcc" "riece-unread" "riece-url" "riece-yank"))
(custom-add-loads 'riece-mini '("riece-mini"))
(custom-add-loads 'riece-hangman '("riece-hangman"))
(custom-add-loads 'riece-highlight-faces '("riece-ctcp" "riece-highlight" "riece-history" "riece-keyword" "riece-log" "riece-unread"))
(custom-add-loads 'riece-layout '("riece-layout"))
(custom-add-loads 'riece-options '("riece-options" "riece-version"))
(custom-add-loads 'riece-server '("riece-options"))

;;; custom-load.el ends here

==> riece-1.22-pkg.tar.gz: lisp/riece/custom-load.el <==
;;; custom-load.el --- automatically extracted custom dependencies

;;; Code:

(autoload 'custom-add-loads "cus-load")

(custom-add-loads 'riece-yank '("riece-yank"))
(custom-add-loads 'riece-eval-ruby '("riece-eval-ruby"))
(custom-add-loads 'riece-ignore '("riece-ignore"))
(custom-add-loads 'riece-guess '("riece-guess"))
(custom-add-loads 'riece-keepalive '("riece-keepalive"))
(custom-add-loads 'riece-coding '("riece-coding" "riece-identity"))
(custom-add-loads 'riece-doctor '("riece-doctor"))
(custom-add-loads 'riece-history '("riece-history"))
(custom-add-loads 'riece-async '("riece-async"))
(custom-add-loads 'riece-keyword '("riece-keyword"))
(custom-add-loads 'riece-url '("riece-url"))
(custom-add-loads 'riece-alias '("riece-alias"))
(custom-add-loads 'riece-looks '("riece-options" "riece-xfaceb"))
(custom-add-loads 'riece-shrink-buffer '("riece-shrink-buffer"))
(custom-add-loads 'riece-channel '("riece-options"))
(custom-add-loads 'riece-ruby '("riece-ruby"))
(custom-add-loads 'riece-addon-list '("riece-addon"))
(custom-add-loads 'riece-highlight '("riece-highlight"))
(custom-add-loads 'riece-biff '("riece-biff"))
(custom-add-loads 'riece-message '("riece-message"))
(custom-add-loads 'riece-eval '("riece-eval"))
(custom-add-loads 'riece-log '("riece-log"))
(custom-add-loads 'riece-ndcc '("riece-ndcc"))
(custom-add-loads 'riece-rdcc '("riece-rdcc"))
(custom-add-loads 'riece-google '("riece-google"))
(custom-add-loads 'riece-ctlseq '("riece-ctlseq"))
(custom-add-loads 'riece-addon-list-faces '("riece-addon"))
(custom-add-loads 'riece '("riece-addon" "riece-alias" "riece-async" "riece-biff" "riece-coding" "riece-ctlseq" "riece-doctor" "riece-eval-ruby" "riece-eval" "riece-google" "riece-guess" "riece-hangman" "riece-highlight" "riece-history" "riece-ignore" "riece-keepalive" "riece-keyword" "riece-layout" "riece-log" "riece-message" "riece-mini" "riece-ndcc" "riece-options" "riece-rdcc" "riece-ruby" "riece-shrink-buffer" "riece-unread" "riece-url" "riece-yank"))
(custom-add-loads 'riece-mini '("riece-mini"))
(custom-add-loads 'riece-hangman '("riece-hangman"))
(custom-add-loads 'riece-highlight-faces '("riece-ctcp" "riece-highlight" "riece-history" "riece-keyword" "riece-log" "riece-unread"))
(custom-add-loads 'riece-layout '("riece-layout"))
(custom-add-loads 'riece-options '("riece-options" "riece-version"))
(custom-add-loads 'riece-server '("riece-options"))

;;; custom-load.el ends here
